@@ -1,6 +1,6 @@
 /*
 **  Xbox360 USB Gamepad Userspace Driver
-**  Copyright (C) 2011 Ingo Ruhnke <grumbel@gmx.de>
+**  Copyright (C) 2011 Ingo Ruhnke <grumbel@gmail.com>
 **
 **  This program is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -19,20 +19,21 @@
 #ifndef HEADER_XBOXDRV_AXISFILTER_LOG_AXIS_FILTER_HPP
 #define HEADER_XBOXDRV_AXISFILTER_LOG_AXIS_FILTER_HPP
 
+#include <string>
+
 #include "axis_filter.hpp"
 
-class LogAxisFilter : public AxisFilter
-{
-public: 
+class LogAxisFilter : public AxisFilter {
+ public:
   static LogAxisFilter* from_string(const std::string& str);
 
-public:
+ public:
   LogAxisFilter(const std::string& name);
 
   int filter(int value, int min, int max);
   std::string str() const;
 
-private:
+ private:
   std::string m_name;
 };
 
