@@ -1,6 +1,6 @@
 /*
 **  Xbox360 USB Gamepad Userspace Driver
-**  Copyright (C) 2011 Ingo Ruhnke <grumbel@gmx.de>
+**  Copyright (C) 2011 Ingo Ruhnke <grumbel@gmail.com>
 **
 **  This program is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -18,22 +18,20 @@
 
 #include "controller_options.hpp"
 
-ControllerOptions::ControllerOptions() :
-  uinput(),
-  modifier(),
-  buttonmap(new ButtonmapModifier),
-  axismap(new AxismapModifier),
-  deadzone(0),
-  deadzone_trigger(0),
-  square_axis(false),
-  four_way_restrictor(0),
-  dpad_rotation(0),
+ControllerOptions::ControllerOptions()
+    : uinput(),
+      modifier(),
+      buttonmap(new ButtonmapModifier),
+      axismap(new AxismapModifier),
+      deadzone(0),
+      deadzone_trigger(0),
+      square_axis(false),
+      four_way_restrictor(0),
+      dpad_rotation(0),
 
-  calibration_map(),
-  sensitivity_map(),
-  relative_axis_map(),
-  autofire_map()
-{
-}
+      calibration_map(),
+      sensitivity_map(),
+      relative_axis_map(),
+      autofire_map() {}
 
 /* EOF */
