@@ -1,6 +1,6 @@
 /*
 **  Xbox360 USB Gamepad Userspace Driver
-**  Copyright (C) 2011 Ingo Ruhnke <grumbel@gmx.de>
+**  Copyright (C) 2011 Ingo Ruhnke <grumbel@gmail.com>
 **
 **  This program is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 #define HEADER_XBOXDRV_DBUS_SUBSYSTEM_HPP
 
 #include <dbus/dbus-glib.h>
+
 #include <string>
 #include <vector>
 
@@ -27,22 +28,21 @@
 
 class XboxdrvDaemon;
 
-class DBusSubsystem
-{
-private:
+class DBusSubsystem {
+ private:
   DBusGConnection* m_connection;
 
-public:
-  DBusSubsystem(const std::string& name);
+ public:
+  DBusSubsystem(const std::string& name, DBusBusType bus_type);
   ~DBusSubsystem();
 
   void register_xboxdrv_daemon(XboxdrvDaemon* c_daemon);
   void register_controller_slots(const std::vector<ControllerSlotPtr>& slots);
 
-private:
+ private:
   void request_name(const std::string& name);
 
-private:
+ private:
   DBusSubsystem(const DBusSubsystem&);
   DBusSubsystem& operator=(const DBusSubsystem&);
 };
