@@ -1,6 +1,6 @@
 /*
 **  Xbox360 USB Gamepad Userspace Driver
-**  Copyright (C) 2011 Ingo Ruhnke <grumbel@gmx.de>
+**  Copyright (C) 2011 Ingo Ruhnke <grumbel@gmail.com>
 **
 **  This program is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -19,26 +19,27 @@
 #ifndef HEADER_XBOXDRV_UI_REL_EVENT_EMITTER_HPP
 #define HEADER_XBOXDRV_UI_REL_EVENT_EMITTER_HPP
 
+#include <memory>
+
 #include "ui_event_emitter.hpp"
 
 class UIRelEventCollector;
 
-class UIRelEventEmitter : public UIEventEmitter
-{
-private:
+class UIRelEventEmitter : public UIEventEmitter {
+ private:
   UIRelEventCollector& m_collector;
 
-public:
+ public:
   UIRelEventEmitter(UIRelEventCollector& collector);
 
   void send(int value);
 
-private:
+ private:
   UIRelEventEmitter(const UIRelEventEmitter&);
   UIRelEventEmitter& operator=(const UIRelEventEmitter&);
 };
 
-typedef boost::shared_ptr<UIRelEventEmitter> UIRelEventEmitterPtr;
+typedef std::shared_ptr<UIRelEventEmitter> UIRelEventEmitterPtr;
 
 #endif
 
