@@ -1,6 +1,6 @@
 /*
 **  Xbox360 USB Gamepad Userspace Driver
-**  Copyright (C) 2011 Ingo Ruhnke <grumbel@gmx.de>
+**  Copyright (C) 2011 Ingo Ruhnke <grumbel@gmail.com>
 **
 **  This program is free software: you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
@@ -20,10 +20,8 @@
 
 #include "path.hpp"
 
-int main(int argc, char** argv)
-{
-  for(int i = 1; i < argc; ++i)
-  {
+int main(int argc, char** argv) {
+  for (int i = 1; i < argc; ++i) {
     std::cout << '"' << argv[i] << '"' << std::endl;
     std::cout << '"' << path::dirname(argv[i]) << '"' << std::endl;
     std::cout << std::endl;
